@@ -27,6 +27,9 @@
     @license: GNU GPL, see COPYING for details.
 """
 
+from datetime import datetime
+import hmac, hashlib
+
 from MoinMoin import log
 logging = log.getLogger(__name__)
 
@@ -37,7 +40,6 @@ import mimetypes
 from MoinMoin import config, caching
 from MoinMoin.util import filesys
 from MoinMoin.action import AttachFile
-from MoinMoin.support.python_compatibility import hmac_new
 
 action_name = __name__.split('.')[-1]
 
@@ -97,10 +99,23 @@ def key(request, wikiname=None, itemname=None, attachname=None, content=None, se
         raise AssertionError('cache_key called with unsupported parameters')
 
     hmac_data = hmac_data.encode('utf-8')
-    key = hmac_new(secret, hmac_data).hexdigest()
+    key = hmac.new(secret, hmac_data, digestmod=hashlib.sha1).hexdigest()
     return key
 
 
+def valid_key(key):
+    # make sure the key looks like keys generated by key()
+    if not isinstance(key, unicode):
+        # key is None (not given in url args) or something unexpected
+        return False
+    try:
+        int(key, 16)  # try to evaluate as hex number
+    except ValueError:
+        # was not a hex number
+        return False
+    return len(key) == 40  # hmac-sha1 hexdigest == 40 hex chars
+
+
 def put(request, key, data,
         filename=None,
         content_type=None,
@@ -202,7 +217,7 @@ def _get_headers(request, key):
     """ get last_modified and headers cached for key """
     meta_cache = caching.CacheEntry(request, cache_arena, key+'.meta', cache_scope, do_locking=do_locking, use_pickle=True)
     meta = meta_cache.content()
-    return meta['httpdate_last_modified'], meta['headers']
+    return meta['last_modified'], meta['headers']
 
 
 def _get_datafile(request, key):
@@ -216,7 +231,7 @@ def _do_get(request, key):
     """ send a complete http response with headers/data cached for key """
     try:
         last_modified, headers = _get_headers(request, key)
-        if request.if_modified_since == last_modified:
+        if datetime.utcfromtimestamp(int(last_modified)) == request.if_modified_since:
             request.status_code = 304
         else:
             for k, v in headers:
@@ -232,14 +247,14 @@ def _do_remove(request, key):
     remove(request, key)
 
 
-def _do(request, do, key):
-    if do == 'get':
-        _do_get(request, key)
-    elif do == 'remove':
-        _do_remove(request, key)
-
 def execute(pagename, request):
     do = request.values.get('do')
     key = request.values.get('key')
-    _do(request, do, key)
+    valid = valid_key(key)  # validate untrusted input
+    if valid and do == 'get':
+        _do_get(request, key)
+    elif valid and do == 'remove':
+        _do_remove(request, key)
+    else:
+        request.status_code = 404
 
