@@ -13,7 +13,7 @@ from xml.dom import Node
 
 from MoinMoin import config, wikiutil
 from MoinMoin.error import ConvertError
-from werkzeug import url_decode
+from werkzeug.urls import url_decode
 from MoinMoin.parser.text_moin_wiki import Parser as WikiParser
 interwiki_re = re.compile(WikiParser.interwiki_rule, re.VERBOSE|re.UNICODE)
 
@@ -1077,7 +1077,7 @@ class convert_tree(visitor):
                 align += self._alignment.get(value, "")
         if node.hasAttribute("width"):
             value = node.getAttribute("width")
-            if value[-1] == "%":
+            if value and value[-1] == "%":
                 align += value
             else:
                 result.append('width="%s"' % self._check_length(value))
