@@ -14,7 +14,6 @@ from MoinMoin.formatter import FormatterBase
 from MoinMoin import wikiutil, i18n
 from MoinMoin.Page import Page
 from MoinMoin.action import AttachFile
-from MoinMoin.support.python_compatibility import set
 
 # insert IDs into output wherever they occur
 # warning: breaks toggle line numbers javascript
@@ -189,6 +188,11 @@ class Formatter(FormatterBase):
         self._in_code_line = 0
         self._code_area_js = 0
         self._code_area_state = ['', 0, -1, -1, 0]
+
+        # code format string. id - code block id, num - line number.
+        # Caution: upon changing, also check line numbers hide/show js.
+        self._code_id_format = "%(id)s_%(num)d"
+
         self._show_section_numbers = None
         self.pagelink_preclosed = False
         self._is_included = kw.get('is_included', False)
@@ -410,7 +414,7 @@ class Formatter(FormatterBase):
         """
 
         if hasattr(self, 'page'):
-            self.request.begin_include(self.page.page_name)
+            self.request.uid_generator.begin(self.page.page_name)
 
         result = []
         # Use the content language
@@ -434,7 +438,7 @@ class Formatter(FormatterBase):
         result.append(self.anchordef('bottom'))
         result.append(self._close('div', newline=newline))
         if hasattr(self, 'page'):
-            self.request.end_include()
+            self.request.uid_generator.end()
         return ''.join(result)
 
     def lang(self, on, lang_name):
@@ -625,7 +629,7 @@ class Formatter(FormatterBase):
                     kw['title'] = "attachment:%s" % url
                 kw['css'] = 'attachment'
             else:
-                target = AttachFile.getAttachUrl(pagename, fname, self.request, upload=True)
+                target = AttachFile.getAttachUrl(pagename, fname, self.request, do='upload_form')
                 kw['title'] = _('Upload new attachment "%(filename)s"') % {'filename': fname}
                 kw['css'] = 'attachment nonexistent'
             return self.url(on, target, **kw)
@@ -639,7 +643,7 @@ class Formatter(FormatterBase):
         exists = AttachFile.exists(self.request, pagename, fname)
         if exists:
             kw['css'] = 'attachment'
-            kw['src'] = AttachFile.getAttachUrl(pagename, filename, self.request, addts=1)
+            kw['src'] = AttachFile.getAttachUrl(pagename, fname, self.request, addts=1)
             title = _('Inlined image: %(url)s') % {'url': self.text(url)}
             if not 'title' in kw:
                 kw['title'] = title
@@ -651,66 +655,19 @@ class Formatter(FormatterBase):
             title = _('Upload new attachment "%(filename)s"') % {'filename': fname}
             img = self.icon('attachimg')
             css = 'nonexistent'
-            target = AttachFile.getAttachUrl(pagename, fname, self.request, upload=True)
+            target = AttachFile.getAttachUrl(pagename, fname, self.request, do='upload_form')
             return self.url(1, target, css=css, title=title) + img + self.url(0)
 
     def attachment_drawing(self, url, text, **kw):
-        # XXX text arg is unused!
-        _ = self.request.getText
-        pagename, filename = AttachFile.absoluteName(url, self.page.page_name)
-        fname = wikiutil.taintfilename(filename)
-        drawing = fname
-        fname = fname + u".png"
-        filename = filename + u".png"
-        # fallback for old gif drawings (1.1 -> 1.2)
-        exists = AttachFile.exists(self.request, pagename, fname)
-        if not exists:
-            gfname = fname[:-4] + u".gif"
-            gfilename = filename[:-4] + u".gif"
-            exists = AttachFile.exists(self.request, pagename, gfname)
-            if exists:
-                fname, filename = gfname, gfilename
-
-        # check whether attachment exists, possibly point to upload form
-        drawing_url = AttachFile.getAttachUrl(pagename, fname, self.request, drawing=drawing, upload=True)
-        if not exists:
-            title = _('Create new drawing "%(filename)s (opens in new window)"') % {'filename': fname}
-            img = self.icon('attachimg')  # TODO: we need a new "drawimg" in similar grey style and size
-            css = 'nonexistent'
-            return self.url(1, drawing_url, css=css, title=title) + img + self.url(0)
-
-        title = _('Edit drawing %(filename)s (opens in new window)') % {'filename': self.text(fname)}
-        kw['src'] = AttachFile.getAttachUrl(pagename, filename, self.request, addts=1)
-        kw['css'] = 'drawing'
-
-        mappath = AttachFile.getFilename(self.request, pagename, drawing + u'.map')
+        # ToDo try to move this to a better place e.g. __init__
         try:
-            map = file(mappath, 'r').read()
-        except (IOError, OSError):
-            map = ''
-        if map:
-            # we have a image map. inline it and add a map ref to the img tag
-            mapid = 'ImageMapOf' + drawing
-            map = map.replace('%MAPNAME%', mapid)
-            # add alt and title tags to areas
-            map = re.sub('href\s*=\s*"((?!%TWIKIDRAW%).+?)"', r'href="\1" alt="\1" title="\1"', map)
-            map = map.replace('%TWIKIDRAW%"', '%s" alt="%s" title="%s"' % (drawing_url, title, title))
-            # unxml, because 4.01 concrete will not validate />
-            map = map.replace('/>', '>')
-            title = _('Clickable drawing: %(filename)s') % {'filename': self.text(fname)}
-            if 'title' not in kw:
-                kw['title'] = title
-            if 'alt' not in kw:
-                kw['alt'] = kw['title']
-            kw['usemap'] = '#'+mapid
-            return map + self.image(**kw)
-        else:
-            if 'title' not in kw:
-                kw['title'] = title
-            if 'alt' not in kw:
-                kw['alt'] = kw['title']
-            return self.url(1, drawing_url) + self.image(**kw) + self.url(0)
-
+            drawing_action = AttachFile.get_action(self.request, url, do='modify')
+            assert drawing_action is not None
+            attachment_drawing = wikiutil.importPlugin(self.request.cfg, 'action',
+                                              drawing_action, 'attachment_drawing')
+            return attachment_drawing(self, url, text, **kw)
+        except (wikiutil.PluginMissingError, wikiutil.PluginAttributeError, AssertionError):
+            return url
 
     # Text ##############################################################
 
@@ -866,32 +823,40 @@ function nformat(num,chrs,add) {
 }
 function addnumber(did, nstart, nstep) {
   var c = document.getElementById(did), l = c.firstChild, n = 1;
-  if (!isnumbered(c))
+  if (!isnumbered(c)) {
     if (typeof nstart == 'undefined') nstart = 1;
     if (typeof nstep  == 'undefined') nstep = 1;
-    n = nstart;
+    var n = nstart;
     while (l != null) {
       if (l.tagName == 'SPAN') {
         var s = document.createElement('SPAN');
-        s.className = 'LineNumber'
-        s.appendChild(document.createTextNode(nformat(n,4,' ')));
+        var a = document.createElement('A');
+        s.className = 'LineNumber';
+        a.appendChild(document.createTextNode(nformat(n,4,'')));
+        a.href = '#' + did + '_' + n;
+        s.appendChild(a);
+        s.appendChild(document.createTextNode(' '));
         n += nstep;
-        if (l.childNodes.length)
-          l.insertBefore(s, l.firstChild)
-        else
-          l.appendChild(s)
+        if (l.childNodes.length) {
+          l.insertBefore(s, l.firstChild);
+        }
+        else {
+          l.appendChild(s);
+        }
       }
       l = l.nextSibling;
     }
+  }
   return false;
 }
 function remnumber(did) {
   var c = document.getElementById(did), l = c.firstChild;
-  if (isnumbered(c))
+  if (isnumbered(c)) {
     while (l != null) {
       if (l.tagName == 'SPAN' && l.firstChild.className == 'LineNumber') l.removeChild(l.firstChild);
       l = l.nextSibling;
     }
+  }
   return false;
 }
 function togglenumber(did, nstart, nstep) {
@@ -906,7 +871,7 @@ function togglenumber(did, nstart, nstep) {
 </script>
 """
 
-    def code_area(self, on, code_id, code_type='code', show=0, start=-1, step=-1):
+    def code_area(self, on, code_id, code_type='code', show=0, start=-1, step=-1, msg=None):
         """Creates a formatted code region, with line numbering.
 
         This region is formatted as a <div> with a <pre> inside it.  The
@@ -919,6 +884,8 @@ function togglenumber(did, nstart, nstep) {
 
         Call once with on=1 to start the region, and a second time
         with on=0 to end it.
+
+        the msg string is not escaped
         """
         _ = self.request.getText
         res = []
@@ -930,7 +897,13 @@ function togglenumber(did, nstart, nstep) {
             self._in_code_area = 1
             self._in_code_line = 0
             # id in here no longer used
-            self._code_area_state = [None, show, start, step, start]
+            self._code_area_state = [None, show, start, step, start, ci]
+
+            if msg:
+                attr = {'class': 'codemsg'}
+                res.append(self._open('div', attr={'class': 'codemsg'}))
+                res.append(msg)
+                res.append(self._close('div'))
 
             # Open the code div - using left to right always!
             attr = {'class': 'codearea', 'lang': 'en', 'dir': 'ltr'}
@@ -975,7 +948,10 @@ document.write('<a href="#" onclick="return togglenumber(\'%s\', %d, %d);" \
         if on:
             res += '<span class="line">'
             if self._code_area_state[1] > 0:
-                res += '<span class="LineNumber">%4d </span>' % (self._code_area_state[4], )
+                res += ('<span class="LineNumber"><a href="#%(fmt)s">%%(num)4d</a> </span><span class="LineAnchor" id="%(fmt)s"></span>' % {'fmt': self._code_id_format, }) % {
+                    'id': self._code_area_state[5],
+                    'num': self._code_area_state[4],
+                    }
                 self._code_area_state[4] += self._code_area_state[3]
         self._in_code_line = on != 0
         return res
