@@ -3,17 +3,18 @@
     MoinMoin - Package Installer
 
     @copyright: 2005 MoinMoin:AlexanderSchremmer,
-                2007 MoinMoin:ReimarBauer
+                2007-2010 MoinMoin:ReimarBauer
     @license: GNU GPL, see COPYING for details.
 """
 
-import os, sys
+import os, re, sys
 import zipfile
 
 from MoinMoin import config, wikiutil, caching, user
 from MoinMoin.Page import Page
 from MoinMoin.PageEditor import PageEditor
 from MoinMoin.logfile import editlog, eventlog
+from MoinMoin.util import filesys
 
 MOIN_PACKAGE_FILE = 'MOIN_PACKAGE'
 MAX_VERSION = 1
@@ -138,7 +139,7 @@ class ScriptEngine:
             if not os.path.exists(target):
                 self._extractToFile(zipname, target)
                 if os.path.exists(target):
-                    os.chmod(target, config.umask )
+                    filesys.chmod(target, 0666 & config.umask)
                     action = 'ATTNEW'
                     edit_logfile_append(self, pagename, path, rev, action, logname='edit-log',
                                        comment=u'%(filename)s' % {"filename": filename}, author=author)
@@ -201,7 +202,9 @@ class ScriptEngine:
 
         from MoinMoin.version import release
         version_int = [int(x) for x in version.split(".")]
-        release = [int(x) for x in release.split(".")]
+        # use a regex here to get only the numbers of the release string (e.g. ignore betaX)
+        release = re.compile('\d+').findall(release)[0:3]
+        release = [int(x) for x in release]
         if version_int > release:
             if lines > 0:
                 self.goto = lines
@@ -225,11 +228,11 @@ class ScriptEngine:
         _ = self.request.getText
         if self.themename is None:
             raise RuntimeScriptException(_("The theme name is not set."))
-        sa = getattr(self.request, "sareq", None)
-        if sa is None:
-            raise RuntimeScriptException(_("Installing theme files is only supported "
-                                           "for standalone type servers."))
-        htdocs_dir = sa.server.htdocs
+
+        from MoinMoin.web.static import STATIC_FILES_PATH as htdocs_dir
+        if not os.access(htdocs_dir, os.W_OK):
+            raise RuntimeScriptException(_("Theme files not installed! Write rights missing for %s.") % htdocs_dir)
+
         theme_file = os.path.join(htdocs_dir, self.themename,
                                   wikiutil.taintfilename(ftype),
                                   wikiutil.taintfilename(target))
@@ -302,7 +305,6 @@ class ScriptEngine:
                 pass
             else:
                 self.msg += u"%(pagename)s added \n" % {"pagename": pagename}
-                page.clean_acl_cache()
         else:
             self.msg += u"action add revision: not enough rights - nothing done \n"
 
@@ -342,6 +344,30 @@ class ScriptEngine:
         else:
             self.msg += u"action delete page: not enough rights - nothing done \n"
 
+    def do_replaceunderlayattachment(self, zipname, filename, pagename, author=u"Scripting Subsystem", comment=u""):
+        """
+        overwrite underlay attachments
+
+        @param pagename: Page where the file is attached. Or in 2.0, the file itself.
+        @param zipname: Filename of the attachment from the zip file
+        @param filename: Filename of the attachment (just applicable for MoinMoin < 2.0)
+        """
+        if self.request.user.may.write(pagename):
+            _ = self.request.getText
+            filename = wikiutil.taintfilename(filename)
+            zipname = wikiutil.taintfilename(zipname)
+            page = PageEditor(self.request, pagename, do_editor_backup=0, uid_override=author)
+            pagedir = page.getPagePath(use_underlay=1, check_create=1)
+            attachments = os.path.join(pagedir, 'attachments')
+            if not os.path.exists(attachments):
+                os.mkdir(attachments)
+            target = os.path.join(attachments, filename)
+            self._extractToFile(zipname, target)
+            if os.path.exists(target):
+                filesys.chmod(target, 0666 & config.umask)
+        else:
+            self.msg += u"action replace underlay attachment: not enough rights - nothing done \n"
+
     def do_replaceunderlay(self, filename, pagename):
         """
         Overwrites underlay pages. Implementational detail: This needs to be
@@ -367,15 +393,8 @@ class ScriptEngine:
 
         pagefile = os.path.join(revdir, revstr)
         self._extractToFile(filename, pagefile)
-
         # Clear caches
-        try:
-            del self.request.cfg.DICTS_DATA
-        except AttributeError:
-            pass
-        self.request.pages = {}
-        caching.CacheEntry(self.request, 'wikidicts', 'dicts_groups', scope='wiki').remove()
-        page.clean_acl_cache()
+        # TODO Code from MoinMoin/script/maint/cleancache.py may be used
 
     def runScript(self, commands):
         """ Runs the commands.
@@ -410,7 +429,12 @@ class ScriptEngine:
             if fnname == '':
                 continue
             try:
-                fn = getattr(self, "do_" + fnname)
+                if fnname in self.request.cfg.packagepages_actions_excluded:
+                    self.msg += u"action package %s: excluded \n" % elements[0].strip()
+                    success = False
+                    continue
+                else:
+                    fn = getattr(self, "do_" + fnname)
             except AttributeError:
                 self.msg += u"Exception RuntimeScriptException: %s\n" % (
                         _("Unknown function %(func)s in line %(lineno)i.") %
@@ -526,12 +550,11 @@ Example:
     if len(args) > 3:
         request_url = args[3]
     else:
-        request_url = "localhost/"
+        request_url = None
 
     # Setup MoinMoin environment
-    from MoinMoin.request import request_cli
-    request = request_cli.Request(url=request_url)
-    request.form = request.args = request.setup_args()
+    from MoinMoin.web.contexts import ScriptContext
+    request = ScriptContext(url=request_url)
 
     package = ZipPackage(request, packagefile)
     if not package.isPackage():
