@@ -15,7 +15,6 @@ logging = log.getLogger(__name__)
 
 from MoinMoin import config, wikiutil, macro
 from MoinMoin.Page import Page
-from MoinMoin.support.python_compatibility import rsplit, set
 
 Dependencies = ['user'] # {{{#!wiki comment ... }}} has different output depending on the user's profile settings
 
@@ -32,6 +31,7 @@ class Parser:
         Methods named like _*_repl() are responsible to handle the named regex patterns.
     """
 
+    extensions = ['.moin']
     # allow caching
     caching = 1
     Dependencies = Dependencies
@@ -42,7 +42,7 @@ class Parser:
  Links:: <<Verbatim(JoinCapitalizedWords)>>; <<Verbatim([[target|linktext]])>>.
  Tables:: || cell text |||| cell text spanning 2 columns ||;    no trailing white space allowed after tables or titles.
 
-(!) For more help, see HelpOnEditing or SyntaxReference.
+(!) For more help, see HelpOnEditing or HelpOnMoinWikiSyntax.
 """)
 
     # some common strings
@@ -600,7 +600,8 @@ class Parser:
             text = groups.get('interwiki')
             return self.formatter.text(text)
         else:
-            return (self.formatter.interwikilink(1, wiki, page) +
+            page, anchor = wikiutil.split_anchor(page)
+            return (self.formatter.interwikilink(1, wiki, page, anchor=anchor) +
                     self.formatter.text(page) +
                     self.formatter.interwikilink(0, wiki, page))
     _interwiki_wiki_repl = _interwiki_repl
@@ -623,11 +624,7 @@ class Parser:
         if abs_name == current_page:
             return self.formatter.text(word)
         else:
-            # handle anchors
-            try:
-                abs_name, anchor = rsplit(abs_name, "#", 1)
-            except ValueError:
-                anchor = ""
+            abs_name, anchor = wikiutil.split_anchor(abs_name)
             return (bang +
                     self.formatter.pagelink(1, abs_name, anchor=anchor) +
                     self.formatter.text(word) +
@@ -695,7 +692,7 @@ class Parser:
     def _transclude_repl(self, word, groups):
         """Handles transcluding content, usually embedding images."""
         target = groups.get('transclude_target', '')
-        target = wikiutil.url_unquote(target, want_unicode=True)
+        target = wikiutil.url_unquote(target)
         desc = groups.get('transclude_desc', '') or ''
         params = groups.get('transclude_params', u'') or u''
         acceptable_attrs_img = ['class', 'title', 'longdesc', 'width', 'height', 'align', ] # no style because of JS
@@ -726,7 +723,7 @@ class Parser:
 
             elif m.group('attach_scheme'):
                 scheme = m.group('attach_scheme')
-                url = wikiutil.url_unquote(m.group('attach_addr'), want_unicode=True)
+                url = wikiutil.url_unquote(m.group('attach_addr'))
                 if scheme == 'attachment':
                     mt = wikiutil.MimeType(filename=url)
                     if mt.major == 'text':
@@ -742,9 +739,10 @@ class Parser:
                         return self.formatter.attachment_image(url, **tag_attrs)
                     else:
                         from MoinMoin.action import AttachFile
-                        pagename = self.formatter.page.page_name
-                        if AttachFile.exists(self.request, pagename, url):
-                            href = AttachFile.getAttachUrl(pagename, url, self.request, escaped=0)
+                        current_pagename = self.formatter.page.page_name
+                        pagename, filename = AttachFile.absoluteName(url, current_pagename)
+                        if AttachFile.exists(self.request, pagename, filename):
+                            href = AttachFile.getAttachUrl(pagename, filename, self.request)
                             tag_attrs, query_args = self._get_params(params,
                                                                      tag_attrs={'title': desc, },
                                                                      acceptable_attrs=acceptable_attrs_object)
@@ -768,8 +766,16 @@ class Parser:
                             pagename = self.formatter.page.page_name
                             return m.execute('EmbedObject', u'target=%s' % url)
                 elif scheme == 'drawing':
+                    url = wikiutil.drawing2fname(url)
                     desc = self._transclude_description(desc, url)
-                    return self.formatter.attachment_drawing(url, desc)
+                    if desc:
+                        tag_attrs= {'alt': desc, 'title': desc, }
+                    else:
+                        tag_attrs = {}
+                    tag_attrs, query_args = self._get_params(params,
+                                                             tag_attrs=tag_attrs,
+                                                             acceptable_attrs=acceptable_attrs_img)
+                    return self.formatter.attachment_drawing(url, desc, **tag_attrs)
 
             elif m.group('page_name'):
                 # experimental client side transclusion
@@ -846,7 +852,7 @@ class Parser:
         target = groups.get('link_target', '')
         desc = groups.get('link_desc', '') or ''
         params = groups.get('link_params', u'') or u''
-        acceptable_attrs = ['class', 'title', 'target', 'accesskey', ] # no style because of JS
+        acceptable_attrs = ['class', 'title', 'target', 'accesskey', 'rel', ] # no style because of JS
         mt = self.link_target_re.match(target)
         if mt:
             if mt.group('page_name'):
@@ -857,11 +863,7 @@ class Parser:
                 else:
                     err = True
                 if err: # not a interwiki link / not in interwiki map
-                    # handle anchors
-                    try:
-                        page_name, anchor = rsplit(page_name_and_anchor, "#", 1)
-                    except ValueError:
-                        page_name, anchor = page_name_and_anchor, ""
+                    page_name, anchor = wikiutil.split_anchor(page_name_and_anchor)
                     current_page = self.formatter.page.page_name
                     if not page_name:
                         page_name = current_page
@@ -874,10 +876,11 @@ class Parser:
                             self._link_description(desc, target, page_name_and_anchor) +
                             self.formatter.pagelink(0, abs_page_name))
                 else: # interwiki link
+                    page_name, anchor = wikiutil.split_anchor(page_name)
                     tag_attrs, query_args = self._get_params(params,
                                                              tag_attrs={},
                                                              acceptable_attrs=acceptable_attrs)
-                    return (self.formatter.interwikilink(1, wiki_name, page_name, querystr=query_args, **tag_attrs) +
+                    return (self.formatter.interwikilink(1, wiki_name, page_name, anchor=anchor, querystr=query_args, **tag_attrs) +
                             self._link_description(desc, target, page_name) +
                             self.formatter.interwikilink(0, wiki_name, page_name))
 
@@ -893,15 +896,16 @@ class Parser:
 
             elif mt.group('attach_scheme'):
                 scheme = mt.group('attach_scheme')
-                url = wikiutil.url_unquote(mt.group('attach_addr'), want_unicode=True)
+                url = wikiutil.url_unquote(mt.group('attach_addr'))
                 tag_attrs, query_args = self._get_params(params,
                                                          tag_attrs={'title': desc, },
                                                          acceptable_attrs=acceptable_attrs)
-                if scheme == 'attachment':
+                if scheme == 'attachment': # ZZZ
                     return (self.formatter.attachment_link(1, url, querystr=query_args, **tag_attrs) +
                             self._link_description(desc, target, url) +
                             self.formatter.attachment_link(0))
                 elif scheme == 'drawing':
+                    url = wikiutil.drawing2fname(url)
                     return self.formatter.attachment_drawing(url, desc, alt=desc, **tag_attrs)
             else:
                 if desc:
@@ -1420,7 +1424,7 @@ class Parser:
         else:
             return ''
 
-    def format(self, formatter, inhibit_p=False):
+    def format(self, formatter, inhibit_p=False, **kw):
         """ For each line, scan through looking for magic
             strings, outputting verbatim any intervening text.
         """
@@ -1431,6 +1435,10 @@ class Parser:
         rawtext = self.raw.expandtabs()
 
         # go through the lines
+
+        for lineno in range(1, self.start_line + 1):
+            self.request.write(self.formatter.line_anchordef(lineno))
+
         self.lineno = self.start_line
         self.lines = self.eol_re.split(rawtext)
         self.line_is_empty = 0
