@@ -103,7 +103,8 @@ class EventLog:
     def write(self, fname):
         """ write complete event-log to disk """
         if self.data:
-            f = file(fname, 'w')
+            f = file(fname, 'wb') # write in binary mode, so it stays exactly as we write it, even on windows.
+                                  # the code in MoinMoin.logfile also uses binary mode and writes \n only.
             for timestamp, action, kvdict in self.data:
                 pagename = kvdict.get('pagename')
                 if pagename and ('PAGE', pagename) in self.renames:
@@ -160,7 +161,8 @@ class EditLog:
         if self.data:
             editlog = self.data.items()
             editlog.sort()
-            f = file(fname, "w")
+            f = file(fname, 'wb') # write in binary mode, so it stays exactly as we write it, even on windows.
+                                  # the code in MoinMoin.logfile also uses binary mode and writes \n only.
             max_rev = 0
             for key, fields in editlog:
                 timestamp, rev, action, pagename, ip, hostname, userid, extra, comment = fields
