@@ -9,7 +9,7 @@ GPL software, 2003-08-10 Thomas Waldmann
 
 def run():
     import xmlrpclib
-    srcwiki = xmlrpclib.ServerProxy("http://moinmaster.wikiwikiweb.de:8000/?action=xmlrpc2")
+    srcwiki = xmlrpclib.ServerProxy("http://master.moinmo.in/?action=xmlrpc2")
     print srcwiki.HelloWorld("Hello Wiki User!\n")
 
 if __name__ == "__main__":
