@@ -190,12 +190,13 @@ class XapianIndex(BaseIndex):
 
             @param amount: amount of queue entries to process (default: -1 == all)
         """
+        done_count = 0
         try:
             request = self._indexingRequest(self.request)
             connection = self.get_indexer_connection()
             self.touch()
+            total = amount
             try:
-                done_count = 0
                 while amount:
                     # trick: if amount starts from -1, it will never get 0
                     amount -= 1
@@ -205,17 +206,23 @@ class XapianIndex(BaseIndex):
                         # queue empty
                         break
                     else:
-                        logging.debug("got from indexer queue: %r %r %r" % (pagename, attachmentname, revno))
-                        if not attachmentname:
-                            if revno is None:
-                                # generic "index this page completely, with attachments" request
-                                self._index_page(request, connection, pagename, mode='update')
+                        logging.info("got from indexer queue: %r %r %r [%d/%d]" % (
+                            pagename, attachmentname, revno,
+                            done_count, total))
+                        if pagename:
+                            if not attachmentname:
+                                if revno is None:
+                                    # generic "index this page completely, with attachments" request
+                                    self._index_page(request, connection, pagename, mode='update')
+                                else:
+                                    # "index this page revision" request
+                                    self._index_page_rev(request, connection, pagename, revno, mode='update')
                             else:
-                                # "index this page revision" request
-                                self._index_page_rev(request, connection, pagename, revno, mode='update')
-                        else:
-                            # "index this attachment" request
-                            self._index_attachment(request, connection, pagename, attachmentname, mode='update')
+                                # "index this attachment" request
+                                self._index_attachment(request, connection, pagename, attachmentname, mode='update')
+                        else: # pagename == None
+                            # index an additional filesystem file (full path given in attachmentname)
+                            self._index_file(request, connection, attachmentname, mode='update')
                         done_count += 1
             finally:
                 logging.debug("updated xapian index with %d queued updates" % done_count)
@@ -223,6 +230,7 @@ class XapianIndex(BaseIndex):
         except XapianDatabaseLockError:
             # another indexer has locked the index, we can retry it later...
             logging.debug("can't lock xapian index, not doing queued updates now")
+        return done_count
 
     def _get_document(self, connection, doc_id, mtime, mode):
         do_index = False
@@ -349,7 +357,7 @@ class XapianIndex(BaseIndex):
 
             for doc in docs_to_delete:
                 connection.delete(doc.id)
-            logging.debug('page %s (all revs, all attachments) removed from xapian index' % pagename)
+            logging.debug('page %r (all revs, all attachments) removed from xapian index' % pagename)
 
         else:
             if request.cfg.xapian_index_history:
@@ -396,7 +404,7 @@ class XapianIndex(BaseIndex):
         mtime = page.mtime_usecs()
 
         doc = self._get_document(connection, itemid, mtime, mode)
-        logging.debug("%s %s %r" % (pagename, revision, doc))
+        logging.debug("%r %s %r" % (pagename, revision, doc))
         if doc:
             mimetype = 'text/%s' % page.pi['format']  # XXX improve this
 
@@ -439,7 +447,7 @@ class XapianIndex(BaseIndex):
         revision = str(revno)
         itemid = "%s:%s:%s" % (wikiname, pagename, revision)
         connection.delete(itemid)
-        logging.debug('page %s, revision %d removed from index' % (pagename, revno))
+        logging.debug('page %r, revision %d removed from index' % (pagename, revno))
 
     def _index_attachment(self, request, connection, pagename, attachmentname, mode='update'):
         """ Index an attachment
@@ -461,7 +469,7 @@ class XapianIndex(BaseIndex):
         if os.path.exists(filename):
             mtime = wikiutil.timestamp2version(os.path.getmtime(filename))
             doc = self._get_document(connection, itemid, mtime, mode)
-            logging.debug("%s %s %r" % (pagename, attachmentname, doc))
+            logging.debug("%r %r %r" % (pagename, attachmentname, doc))
             if doc:
                 page = Page(request, pagename)
                 mimetype, att_content = self.contentfilter(filename)
@@ -482,12 +490,22 @@ class XapianIndex(BaseIndex):
 
                 self._add_fields_to_document(request, doc, fields, multivalued_fields)
 
-                connection.replace(doc)
-                logging.debug('attachment %s (page %s) updated in index' % (attachmentname, pagename))
+                try:
+                    connection.replace(doc)
+                except xapian.Error, err:
+                    logging.error('attachment %r (page %r) could not be updated in index: %s' % (
+                        attachmentname, pagename, str(err)))
+                else:
+                    logging.debug('attachment %r (page %r) updated in index' % (attachmentname, pagename))
         else:
             # attachment file was deleted, remove it from index also
-            connection.delete(itemid)
-            logging.debug('attachment %s (page %s) removed from index' % (attachmentname, pagename))
+            try:
+                connection.delete(itemid)
+            except xapian.Error, err:
+                logging.error('attachment %r (page %r) could not be removed from index: %s' % (
+                    attachmentname, pagename, str(err)))
+            else:
+                logging.debug('attachment %r (page %r) removed from index' % (attachmentname, pagename))
 
     def _index_file(self, request, connection, filename, mode='update'):
         """ index files (that are NOT attachments, just arbitrary files)
@@ -506,7 +524,7 @@ class XapianIndex(BaseIndex):
             mtime = wikiutil.timestamp2version(os.path.getmtime(filename))
 
             doc = self._get_document(connection, itemid, mtime, mode)
-            logging.debug("%s %r" % (filename, doc))
+            logging.debug("%r %r" % (filename, doc))
             if doc:
                 mimetype, file_content = self.contentfilter(filename)
 
@@ -529,6 +547,27 @@ class XapianIndex(BaseIndex):
         except (OSError, IOError, UnicodeError):
             logging.exception("_index_file crashed:")
 
+    def _queue_pages(self, request, files=None, pages=None):
+        """ Put all (given) pages into indexer queue
+
+        This should be called from queuePages only!
+
+        @param request: request suitable for indexing
+        @param files: an optional list of files to index
+        @param pages: list of pages to index, if not given, all pages are indexed
+        """
+        if pages is None:
+            # Index all pages
+            pages = request.rootpage.getPageList(user='', exists=1)
+
+        logging.info("queuing %d pages..." % len(pages))
+        entries = [(pagename, None, None) for pagename in pages]
+        self.update_queue.mput(entries)
+        if files:
+            logging.info("indexing all files...")
+            entries = [(None, fname.strip(), None) for fname in files]
+            self.update_queue.mput(entries)
+
     def _index_pages(self, request, files=None, mode='update', pages=None):
         """ Index all (given) pages (and all given files)
 
