@@ -4,19 +4,19 @@
 
     This macro creates a pie chart of the type of user agents
     accessing the wiki.
-    
+
     TODO: should be refactored after hitcounts.
 
-    @copyright: 2002-2004 by Jrgen Hermann <jh@web.de>
+    @copyright: 2002-2004 Juergen Hermann <jh@web.de>,
+                2007 MoinMoin:ThomasWaldmann
     @license: GNU GPL, see COPYING for details.
 """
 
 _debug = 0
 
-from MoinMoin import wikiutil, caching 
+from MoinMoin import wikiutil, caching, logfile
 from MoinMoin.Page import Page
-from MoinMoin.util import MoinMoinNoFooter
-from MoinMoin.logfile import eventlog, logfile
+from MoinMoin.logfile import eventlog
 
 
 def linkto(pagename, request, params=''):
@@ -35,9 +35,8 @@ def linkto(pagename, request, params=''):
     querystr = wikiutil.escape(querystr)
     if params:
         querystr += '&amp;' + params
-    
-    # TODO: remove escape=0 in 2.0
-    data = {'url': page.url(request, querystr, escape=0)}
+
+    data = {'url': page.url(request, querystr)}
     data.update(request.cfg.chart_options)
     result = ('<img src="%(url)s" width="%(width)d" height="%(height)d"'
               ' alt="useragents chart">') % data
@@ -47,20 +46,20 @@ def linkto(pagename, request, params=''):
 
 def get_data(request):
     # get results from cache
-    cache = caching.CacheEntry(request, 'charts', 'useragents')
+    cache = caching.CacheEntry(request, 'charts', 'useragents', scope='wiki', use_pickle=True)
     cache_date, data = 0, {}
     if cache.exists():
         try:
-            cache_date, data = eval(cache.content())
+            cache_date, data = cache.content()
         except:
             cache.remove() # cache gone bad
-    
+
     log = eventlog.EventLog(request)
     try:
         new_date = log.date()
     except logfile.LogMissing:
         new_date = None
-    
+
     if new_date is not None:
         log.set_filter(['VIEWPAGE', 'SAVEPAGE'])
         for event in log.reverse():
@@ -68,17 +67,17 @@ def get_data(request):
                 break
             ua = event[2].get('HTTP_USER_AGENT')
             if ua:
-                pos = ua.find(" (compatible; ")
-                if pos >= 0:
+                try:
+                    pos = ua.index(" (compatible; ")
                     ua = ua[pos:].split(';')[1].strip()
-                else:
+                except ValueError:
                     ua = ua.split()[0]
                 #ua = ua.replace(';', '\n')
                 data[ua] = data.get(ua, 0) + 1
-    
+
         # write results to cache
-        cache.update("(%r, %r)" % (new_date, data))
-            
+        cache.update((new_date, data))
+
     data = [(cnt, ua) for ua, cnt in data.items()]
     data.sort()
     data.reverse()
@@ -88,38 +87,39 @@ def text(pagename, request):
     from MoinMoin.util.dataset import TupleDataset, Column
     from MoinMoin.widget.browser import DataBrowserWidget
 
-    fmt = request.formatter
     _ = request.getText
-    
+
     data = get_data(request)
 
-    sum = 0.0
+    total = 0.0
     for cnt, ua in data:
-        sum += cnt
+        total += cnt
 
 
     agents = TupleDataset()
     agents.columns = [Column('agent', label=_("User agent"), align='left'),
-                      Column('value', label= '%', align='right')]
+                      Column('value', label='%', align='right')]
 
     cnt_printed = 0
     data = data[:10]
-    for cnt, ua in data:
-        try:
-            ua = unicode(ua)
-            agents.addRow((ua, "%.2f" % (100.0*cnt/sum)))
-            cnt_printed += cnt
-        except UnicodeError:
-            pass
-    agents.addRow((_('Others'), "%.2f" % (100*(sum-cnt_printed)/sum)))
+
+    if total:
+        for cnt, ua in data:
+            try:
+                ua = wikiutil.escape(unicode(ua))
+                agents.addRow((ua, "%.2f" % (100.0 * cnt / total)))
+                cnt_printed += cnt
+            except UnicodeError:
+                pass
+        if total > cnt_printed:
+            agents.addRow((_('Others'), "%.2f" % (100 * (total - cnt_printed) / total)))
 
     table = DataBrowserWidget(request)
     table.setData(agents)
-    return table.toHTML()
-    
+    return table.render(method="GET")
 
 def draw(pagename, request):
-    import shutil, cStringIO, operator
+    import shutil, cStringIO
     from MoinMoin.stats.chart import Chart, ChartData, Color
 
     _ = request.getText
@@ -136,7 +136,7 @@ def draw(pagename, request):
     maxdata = len(colors) - 1
     if len(data) > maxdata:
         others = [x[0] for x in data[maxdata:]]
-        data = data[:maxdata] + [(reduce(operator.add, others, 0), _('Others').encode('iso-8859-1', 'replace'))] # gdchart can't do utf-8
+        data = data[:maxdata] + [(sum(others), _('Others').encode('iso-8859-1', 'replace'))] # gdchart can't do utf-8
 
     # shift front to end if others is very small
     if data[-1][0] * 10 < data[0][0]:
@@ -148,7 +148,7 @@ def draw(pagename, request):
     # give us a chance to develop this
     if _debug:
         return "<p>data = %s</p>" % \
-            '<br>'.join(map(wikiutil.escape, map(repr, [labels, data])))
+            '<br>'.join([wikiutil.escape(repr(x)) for x in [labels, data]])
 
     # create image
     image = cStringIO.StringIO()
@@ -159,29 +159,24 @@ def draw(pagename, request):
     if request.cfg.sitename: title = "%s: " % request.cfg.sitename
     title = title + _('Distribution of User-Agent Types')
     c.option(
-        pie_color = colors,
-        label_font = Chart.GDC_SMALL,
-        label_line = 1,
-        label_dist = 20,
-        threed_depth = 20,
-        threed_angle = 225,
-        percent_labels = Chart.GDCPIE_PCT_RIGHT,
-        title_font = c.GDC_GIANT,
-        title = title.encode('iso-8859-1', 'replace')) # gdchart can't do utf-8
+        pie_color=colors,
+        label_font=Chart.GDC_SMALL,
+        label_line=1,
+        label_dist=20,
+        threed_depth=20,
+        threed_angle=225,
+        percent_labels=Chart.GDCPIE_PCT_RIGHT,
+        title_font=c.GDC_GIANT,
+        title=title.encode('iso-8859-1', 'replace')) # gdchart can't do utf-8
     labels = [label.encode('iso-8859-1', 'replace') for label in labels]
     c.draw(style,
         (request.cfg.chart_options['width'], request.cfg.chart_options['height']),
         image, labels)
 
-    # send HTTP headers
-    headers = [
-        "Content-Type: image/gif",
-        "Content-Length: %d" % len(image.getvalue()),
-    ]
-    request.http_headers(headers)
+    request.content_type = 'image/gif'
+    request.content_length = len(image.getvalue())
 
     # copy the image
     image.reset()
     shutil.copyfileobj(image, request, 8192)
-    raise MoinMoinNoFooter
 
