@@ -18,11 +18,9 @@ from MoinMoin.util import pysupport
 
 modules = pysupport.getPackageModules(__file__)
 
-# Check whether we can emit a RSS feed.
-# RSS is broken on plain Python 2.4.x, and works only when installing PyXML.
-# News: A user reported that the RSS is valid when using Python 2.5.1 on Windows.
 import sys, xml
-rss_supported = sys.version_info[:3] >= (2, 5, 1) or '_xmlplus' in xml.__file__
+
+rss_supported = True
 
 
 class ThemeBase:
@@ -222,6 +220,32 @@ class ThemeBase:
             html = u''
         return html
 
+    def backlink(self, page, page_name, link_text):
+        """ Create html for the "backlink" part of the title.
+
+        What it will be is determined by calling cfg.backlink_method,
+        which can return 'backlink' (render a linkto-fullsearch link),
+        'pagelink' (render a link to same page) or 'text' (render just text).
+
+        @param page: page object
+        @param page_name: the (full) page name
+        @param link_text: the text shown for the link
+        @return: html fragment
+        """
+        request = self.request
+        _ = request.getText
+        method = request.cfg.backlink_method(request)
+        if method == 'backlink':
+            link_title = _('Click to do a full-text search for this title')
+            link_query = dict(action='fullsearch', value='linkto:"%s"' % page_name, context='180')
+            link = page.link_to(request, link_text, querystr=link_query, title=link_title,
+                                css_class='backlink', rel='nofollow')
+        elif method == 'pagelink':
+            link = page.link_to(request, link_text)
+        else:  # == 'text'
+            link = wikiutil.escape(link_text)
+        return link
+
     def title(self, d):
         """ Assemble the title (now using breadcrumbs)
 
@@ -238,15 +262,7 @@ class ThemeBase:
                 curpage += s
                 content.append("<li>%s</li>" % Page(self.request, curpage).link_to(self.request, s))
                 curpage += '/'
-            link_text = segments[-1]
-            link_title = _('Click to do a full-text search for this title')
-            link_query = {
-                'action': 'fullsearch',
-                'value': 'linkto:"%s"' % d['page_name'],
-                'context': '180',
-            }
-            # we dont use d['title_link'] any more, but make it ourselves:
-            link = d['page'].link_to(self.request, link_text, querystr=link_query, title=link_title, css_class='backlink', rel='nofollow')
+            link = self.backlink(d['page'], d['page_name'], segments[-1])
             content.append(('<li>%s</li>') % link)
         else:
             content.append('<li>%s</li>' % wikiutil.escape(d['title_text']))
@@ -269,13 +285,7 @@ class ThemeBase:
         if d['title_text'] == d['page'].split_title():
             # just showing a page, no action
             segments = d['page_name'].split('/')
-            link_text = segments[-1]
-            link_title = _('Click to do a full-text search for this title')
-            link_query = {'action': 'fullsearch', 'context': '180',
-                          'value': 'linkto:"%s"' % d['page_name'], }
-            link = d['page'].link_to(self.request, link_text,
-                                     querystr=link_query, title=link_title,
-                                     css_class='backlink', rel='nofollow')
+            link = self.backlink(d['page'], d['page_name'], segments[-1])
             if len(segments) <= 1:
                 html = link
             else:
@@ -687,7 +697,7 @@ class ThemeBase:
         if theme:
             href = '%s/%s/css/%s.css' % (self.cfg.url_prefix_static, self.name, href)
         attrs = 'type="text/css" charset="%s" media="%s" href="%s"' % (
-                self.stylesheetsCharset, media, href, )
+                self.stylesheetsCharset, media, wikiutil.escape(href, True), )
         if title:
             return '<link rel="alternate stylesheet" %s title="%s">' % (attrs, title)
         else:
@@ -869,8 +879,10 @@ var search_hint = "%(search_hint)s";
         """
         if not rss_supported:
             return False
-        return page.page_name == u'RecentChanges' or \
-           page.page_name == self.request.getText(u'RecentChanges')
+        return page.page_name in [u'RecentChanges',
+            self.request.getText(u'RecentChanges'),
+            self.request.cfg.page_front_page,
+            self.request.getText(self.request.cfg.page_front_page)]
 
     def rsshref(self, page):
         """ Create rss href, used for rss button and head link
@@ -899,6 +911,15 @@ var search_hint = "%(search_hint)s";
                     u'href="%s" type="application/rss+xml">') % (
                         wikiutil.escape(self.cfg.sitename, True),
                         wikiutil.escape(self.rsshref(page), True) )
+        elif rss_supported and self.cfg.rss_show_page_history_link:
+            link = (u'<link rel="alternate" title="%s: %s" '
+                    u'href="%s" type="application/rss+xml">') % (
+                        wikiutil.escape(self.cfg.sitename, True),
+                        wikiutil.escape(page.page_name, True),
+                        wikiutil.escape(page.url(self.request, querystr={
+                            'action': 'rss_rc', 'ddiffs': '1', 'unique': '0',
+                            'diffs': '1', 'show_att': '1',
+                            'page': page.page_name }, escape=0), True) )
         return link
 
     def html_head(self, d):
@@ -1678,6 +1699,8 @@ var gui_editor_link_text = "%(text)s";
 <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
 <html>
 <head>
+<meta http-equiv="X-UA-Compatible" content="IE=Edge">
+<meta name="viewport" content="width=device-width, initial-scale=1">
 %s
 %s
 %s
@@ -1697,9 +1720,9 @@ var gui_editor_link_text = "%(text)s";
         output.append('<link rel="Start" href="%s">\n' % request.href(page_front_page))
         if pagename:
             output.append('<link rel="Alternate" title="%s" href="%s">\n' % (
-                    _('Wiki Markup'), request.href(pagename, action='raw')))
+                    _('Wiki Markup'), page.url(request, querystr=dict(action='raw'))))
             output.append('<link rel="Alternate" media="print" title="%s" href="%s">\n' % (
-                    _('Print View'), request.href(pagename, action='print')))
+                    _('Print View'), page.url(request, querystr=dict(action='print'))))
 
             # !!! currently disabled due to Mozilla link prefetching, see
             # http://www.mozilla.org/projects/netlib/Link_Prefetching_FAQ.html
@@ -1773,7 +1796,7 @@ var gui_editor_link_text = "%(text)s";
 
         # In standard mode, emit theme.header
         else:
-            exists = pagename and page.exists(includeDeleted=True)
+            exists = pagename and page.exists(includeDeleted=False)
             # prepare dict for theme code:
             d = {
                 'theme': self.name,
