@@ -26,61 +26,72 @@ class Settings(UserPrefBase):
         self.name = 'suid'
 
     def allowed(self):
-        return (UserPrefBase.allowed(self) and
-                self.request.user.isSuperUser() or
-                (not self.request._setuid_real_user is None and
-                 (self.request._setuid_real_user.isSuperUser())))
+        return (self.request.user.auth_method in self.request.cfg.auth_can_logout and
+               UserPrefBase.allowed(self) and self.request.user.isSuperUser())
 
     def handle_form(self):
         _ = self._
-        form = self.request.form
+        request = self.request
+        form = request.form
 
-        if 'cancel' in form:
+        if form.has_key('cancel'):
             return
 
-        if (wikiutil.checkTicket(self.request, self.request.form['ticket'][0])
-            and self.request.request_method == 'POST'):
-            uid = form.get('selected_user', [''])[0]
+        if request.method != 'POST':
+            return
+
+        if not wikiutil.checkTicket(request, form['ticket']):
+            return
+
+        user_name = form.get('user_name', '')
+        if user_name:
+            uid = user.getUserId(request, user_name)
+            if uid:
+                theuser = user.User(request, uid, auth_method='setuid')
+            else:
+                # Don't allow creating users with invalid names
+                if not user.isValidName(request, user_name):
+                    return 'error', _("""Invalid user name {{{'%s'}}}.
+Name may contain any Unicode alpha numeric character, with optional one
+space between words. Group page name is not allowed.""", wiki=True) % wikiutil.escape(user_name)
+                theuser = user.User(request, auth_method='setuid')
+                theuser.name = user_name
+        else:
+            uid = form.get('selected_user', '')
             if not uid:
                 return 'error', _("No user selected")
-            theuser = user.User(self.request, uid, auth_method='setuid')
+            theuser = user.User(request, uid, auth_method='setuid')
             if not theuser or not theuser.exists():
                 return 'error', _("No user selected")
-            # set valid to True so superusers can even switch
-            # to disable accounts
-            theuser.valid = True
-            self.request.session['setuid'] = uid
-            self.request._setuid_real_user = self.request.user
-            # now continue as the other user
-            self.request.user = theuser
-            return  _("You can now change the settings of the selected user account; log out to get back to your account.")
-        else:
-            return None
+        # set valid to True so superusers can even switch
+        # to disable accounts
+        theuser.valid = True
+        request._setuid_real_user = request.user
+        # now continue as the other user
+        request.user = theuser
+        if not uid:
+            # create new user
+            theuser.save()
+        return  _("You can now change the settings of the selected user account; log out to get back to your account.")
 
     def _user_select(self):
         options = []
         users = user.getUserList(self.request)
-        realuid = None
-        if hasattr(self.request, '_setuid_real_user') and self.request._setuid_real_user:
-            realuid = self.request._setuid_real_user.id
-        else:
-            realuid = self.request.user.id
+        current_uid = self.request.user.id
         for uid in users:
-            if uid != realuid:
+            if uid != current_uid:
                 name = user.User(self.request, id=uid).name
                 options.append((uid, name))
         options.sort(lambda x, y: cmp(x[1].lower(), y[1].lower()))
 
-        size = min(5, len(options))
-        current_user = self.request.user.id
-
         if not options:
             _ = self._
             self._only = True
             return _("You are the only user.")
 
         self._only = False
-        return util.web.makeSelection('selected_user', options, current_user, size=size)
+        size = min(10, len(options))
+        return util.web.makeSelection('selected_user', options, current_uid, size=size)
 
     def create_form(self):
         """ Create the complete HTML form code. """
@@ -89,6 +100,7 @@ class Settings(UserPrefBase):
                                           'assume the identity of another user.')))
 
         ticket = wikiutil.createTicket(self.request)
+        self.make_row(_('User'), [html.INPUT(type="text", size="32", name="user_name")], valign="top")
         self.make_row(_('Select User'), [self._user_select()], valign="top")
         form.append(html.INPUT(type="hidden", name="ticket", value="%s" % ticket))
         if not self._only:
